@@ -780,6 +780,8 @@ gdm_server_start (GdmDisplay *disp,
     /* fork X server process */
     gdm_server_spawn (d, vtarg);
 
+    g_free (vtarg);
+
     /* we can now use d->handled since that's set up above */
     do_server_wait (d);
 
@@ -951,17 +953,6 @@ rotate_logs (const char *dname)
 	g_free (fname);
 }
 
-static int
-vector_len (char * const *v)
-{
-        int i;
-        if (v == NULL)
-                return 0;
-        for (i = 0; v[i] != NULL; i++)
-                ;
-        return i;
-}
-
 static void
 gdm_server_add_xserver_args (GdmDisplay *d, char **argv)
 {
@@ -970,7 +961,7 @@ gdm_server_add_xserver_args (GdmDisplay *d, char **argv)
 	int len;
 	int i;
 
-	len = vector_len (argv);
+	len = gdm_vector_len (argv);
 	g_shell_parse_argv (d->xserver_session_args, &count, &args, NULL);
 	argv = g_renew (char *, argv, len + count + 1);
 
@@ -1264,6 +1255,8 @@ gdm_server_spawn (GdmDisplay *d, const char *vtarg)
 			   "gdm_server_spawn", d->name);
 	}
 
+	g_free (logfile);
+
 	/* The X server expects USR1/TTIN/TTOU to be SIG_IGN */
 	ign_signal.sa_handler = SIG_IGN;
 	ign_signal.sa_flags = SA_RESTART;
