@@ -16,7 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <string.h>
@@ -25,6 +26,8 @@
 #include "misc.h"
 #include "gdmconfig.h"
 
+#include "gdm-common.h"
+
 #define INDEX_FILE1 "index.theme"
 #define INDEX_FILE2 "index.theme.disabled"
 
@@ -103,8 +106,7 @@ gdm_set_theme (const char *theme_name)
 gboolean
 gdm_working_command_exists (const char *commands)
 {
-	char *command = ve_get_first_working_command
-		(commands, TRUE /* only_existance */);
+	char *command = ve_get_first_working_command (commands, TRUE /* only_existance */);
 	if (command == NULL)
 		return FALSE;
 	g_free (command);
